<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source> About Boomaga</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thanks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boomaga provides a virtual printer for CUPS. This can be used for print preview or for print booklets.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright: %1-%2 %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Homepage: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Special thanks to:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If you want to help translate, we will be glad to see you in our translation team on &lt;a %1&gt;Transifex server&lt;/a&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boomaga is developed by the &lt;a %1&gt;Boomaga Team and contributors&lt;/a&gt; on GitHub.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BooFile</name>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Divide your long booklets into smaller sub-booklets for printing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print as sub-booklets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum number of sheets in your sub-booklet.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sheets per sub-booklet:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autosave your jobs every time you print.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoSave the recent sessions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow negative page margins:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select directory for saved jobs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory for saved sessions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right-to-left direction</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CupsBooFile</name>
    <message>
        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportToPdf</name>
    <message>
        <source>Print to PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Output file:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Meta info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> The name of the person who created the document.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subject:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> The subject of the document.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> Keywords associated with the document.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keywords:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PDF files (*.pdf);;All files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Overwrite file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A file named &quot;%1&quot; already exists.
Are you sure you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> The document&apos;s title.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InFile</name>
    <message>
        <source>I can&apos;t read file &quot;%1&quot; either because it&apos;s not a supported file type, or because the file has been damaged.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>JobListView</name>
    <message>
        <source>%1 pages</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Booklet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print on both sides of a sheet.</source>
        <comment>MainForm::Double-sided checkbox tooltip</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Double-sided</source>
        <comment>MainForm::Double-sided checkbox</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jobs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print and Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next sheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous sheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Boomaga</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boomaga</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%v of %m</source>
        <comment>Format for QProgressBar (http://qt-project.org/doc/qt-4.8/qprogressbar.html#format-prop)</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print the all pages on %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print the odd pages on %1.&lt;p&gt;When finished, turn the pages, insert them into the printer&lt;br&gt;and click the Continue button.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print the even pages on %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 pages</source>
        <comment>Status bar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 page</source>
        <comment>Status bar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 sheets</source>
        <comment>Status bar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 sheet</source>
        <comment>Status bar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sheet %1 of %2</source>
        <comment>Status bar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert blank page after this page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete this page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert blank page before this page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save project under a new name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open an existing project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page %1</source>
        <comment>&apos;Undo deletion&apos; menu item</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Boomaga files (*.boo);;All files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Project saved successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All supported files (*.pdf *.boo);;Boomaga files (*.boo);;PDF files (*.pdf);;All files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4 up horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4 up vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8 up horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8 up vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start new booklet from this page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t start new booklet from this page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate page to the left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate page to the right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename job</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate job to the left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate job to the right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Job title:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export the project to PDF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clone job...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clone job</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print with options...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select number of copies before printing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sub-booklets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo delete page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page %1 of %2</source>
        <comment>Status bar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recent files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit &amp;job</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Export to PDF...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete pages until the end of the job</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete current job</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto saving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t create directory &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 %2: Page %3</source>
        <comment>&apos;Undo deletion&apos; menu item, (%1 - is a job number, %2 - is a job title, %3 - is a page number in this job</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PostScriptFile</name>
    <message>
        <source>Converting PostScript to PDF</source>
        <comment>Progressbar text</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t start gs converter: &quot;%1&quot;</source>
        <comment>Error message. &apos;gs&apos; is a command line tool from ghostscript</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PrintDialog</name>
    <message>
        <source>Print document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Collate copies:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PrinterSettings</name>
    <message>
        <source>Margins (mm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bottom:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Left:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw border</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print in reverse order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printer has duplexer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manual with reverse (suitable for most printers)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manual without reverse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Preferences of &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Profiles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>+</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Profile %1</source>
        <comment>Defaul name for created printer profile in the Printer Settings diaog</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Force grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Force color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print on both sides</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip on short edge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip on long edge</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Project</name>
    <message>
        <source>Boomaga</source>
        <comment>Error message title</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>I can&apos;t read from file &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <comment>Printer profile default name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (Empty file name)</source>
        <comment>Error message. %1 is a file name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (No such file or directory)</source>
        <comment>Error message. %1 is a file name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot; (Access denied)</source>
        <comment>Error message. %1 is a file name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t open file &quot;%1&quot;</source>
        <comment>Error message. %1 is a file name</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>~/Untitled.pdf</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SubBookletView</name>
    <message>
        <source>Sub-booklet %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 pages</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TmpPdfFile</name>
    <message>
        <source>I can&apos;t create temporary file &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t read file &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t write to file &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I can&apos;t write file &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
